==> sinosun-ui-0.1.3.tgz: package/es/index.js <==
var ENV = process.env.NODE_ENV;
if (ENV !== 'production' && ENV !== 'test' && typeof console !== 'undefined' && console.warn && typeof window !== 'undefined') {
    console.warn('You are using a whole package of sinosun-ui, ' + 'please use https://yqtdev.sinosun.com:18094/static/docs/component/index.html#/./foreword to reduce app bundle size.');
}

/* 通用 */
import SnButton from './button';
import SnIcon from './icon';

/* 布局 */
import SnWingBlank from './wing-blank';
import SnWhiteSpace from './white-space';
import SnFlexBox from './flex-box';
/* 导航 */

/* 数据录入 */
import SnInputItem from './input-item';
import SnDatetimePickerView from './datetime-picker-view';
import SnDatetimePicker from './datetime-picker';
import SnRangePickerView from './range-picker-view';
import SnRangePicker from './range-picker';
import SnPickerView from './picker-view';
import SnPicker from './picker';
import SnSwitch from './switch';
import SnUpload from './upload';
import SnMstpUpload from './mstp-upload';

/* 数据展示 */
import SnListItem from './list-item';
import SnEmpty from './empty';
import SnDropdownMenu from './dropdown-menu';
import SnPopup from './popup';
import SnModal from './modal';
import SnCollapse from './collapse';
import SnCarousel from './carousel';

/* 反馈 */
import SnLoading from './loading';
import SnToast from './toast';

/* 手势 */

/* 组合 */

/* 其他 */
import TransferDom from './directives/transfer-dom';

var components = [SnButton, SnIcon, SnFlexBox, SnWingBlank, SnWhiteSpace, SnInputItem, SnDatetimePickerView, SnDatetimePicker, SnRangePickerView, SnRangePicker, SnPickerView, SnPicker, SnSwitch, SnUpload, SnMstpUpload, SnListItem, SnEmpty, SnDropdownMenu, SnModal, SnCollapse, SnPopup, SnCarousel, SnLoading, SnToast];

var install = function install(Vue) {
    components.map(function (component) {
        Vue.use(component);
    });
};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
}

export { SnButton, SnIcon, SnFlexBox, SnWingBlank, SnWhiteSpace, SnInputItem, SnDatetimePickerView, SnDatetimePicker, SnRangePickerView, SnRangePicker, SnPickerView, SnPicker, SnSwitch, SnUpload, SnMstpUpload, SnListItem, SnEmpty, SnDropdownMenu, SnModal, SnCollapse, SnPopup, SnCarousel, SnLoading, SnToast, TransferDom };

export default {
    install: install
};

==> sinosun-ui-0.1.4.tgz: package/es/index.js <==
var ENV = process.env.NODE_ENV;
if (ENV !== 'production' && ENV !== 'test' && typeof console !== 'undefined' && console.warn && typeof window !== 'undefined') {
    console.warn('You are using a whole package of sinosun-ui, ' + 'please use https://yqtdev.sinosun.com:18094/static/docs/component/index.html#/./foreword to reduce app bundle size.');
}

/* 通用 */
import SnButton from './button';
import SnIcon from './icon';

/* 布局 */
import SnWingBlank from './wing-blank';
import SnWhiteSpace from './white-space';
import SnFlexBox from './flex-box';
/* 导航 */

/* 数据录入 */
import SnInputItem from './input-item';
import SnDatetimePickerView from './datetime-picker-view';
import SnDatetimePicker from './datetime-picker';
import SnRangePickerView from './range-picker-view';
import SnRangePicker from './range-picker';
import SnRadioItem from './radio-item';
import SnCheckItem from './check-item';
import SnPickerView from './picker-view';
import SnPicker from './picker';
import SnSwitch from './switch';
import SnUpload from './upload';
import SnMstpUpload from './mstp-upload';

/* 数据展示 */
import SnListItem from './list-item';
import SnEmpty from './empty';
import SnDropdownMenu from './dropdown-menu';
import SnPopup from './popup';
import SnModal from './modal';
import SnCollapse from './collapse';
import SnCarousel from './carousel';

/* 反馈 */
import SnLoading from './loading';
import SnToast from './toast';

/* 手势 */

/* 组合 */

/* 其他 */
import TransferDom from './directives/transfer-dom';

var components = [SnButton, SnIcon, SnFlexBox, SnWingBlank, SnWhiteSpace, SnInputItem, SnDatetimePickerView, SnDatetimePicker, SnRangePickerView, SnRangePicker, SnRadioItem, SnCheckItem, SnPickerView, SnPicker, SnSwitch, SnUpload, SnMstpUpload, SnListItem, SnEmpty, SnDropdownMenu, SnModal, SnCollapse, SnPopup, SnCarousel, SnLoading, SnToast];

var install = function install(Vue) {
    components.map(function (component) {
        Vue.use(component);
    });
};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
}

export { SnButton, SnIcon, SnFlexBox, SnWingBlank, SnWhiteSpace, SnInputItem, SnDatetimePickerView, SnDatetimePicker, SnRangePickerView, SnRangePicker, SnRadioItem, SnCheckItem, SnPickerView, SnPicker, SnSwitch, SnUpload, SnMstpUpload, SnListItem, SnEmpty, SnDropdownMenu, SnModal, SnCollapse, SnPopup, SnCarousel, SnLoading, SnToast, TransferDom };

export default {
    install: install
};
